window.Gleam.initSearch([{"doc":"filespy","title":"filespy","content":"# filespy\n\n[![Package Version](https://img.shields.io/hexpm/v/filespy)](https://hex.pm/packages/filespy)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/filespy/)\n\nFilespy is a small library and versatile library that allows you to watch for filesystem events from Gleam! It&#39;s a type-safe wrapper around the erlang [FS](https://github.com/5HT/fs) library.\n\n## Quick start\n\nAdd the library to your requirements with `gleam add`:\n\n```sh\ngleam add filespy\n```\n\n**Note**: If you use Linux or a BSD, you need to install `inotify-tools`!\n\n## Usage\n\nThe library is configured via a simple builder:\n\n```gleam\nimport filespy\nimport gleam/io\nimport gleam/erlang/process\n\nfn main() {\n    let _res = filespy.new()   // Create the builder\n    |&gt; filespy.add_dir(&quot;.&quot;)    // Watch the current directory\n    |&gt; filespy.add_dir(&quot;/mnt&quot;) // Watch the /mnt directory\n    |&gt; filespy.set_handler(fn (path, event) {\n        // This callback will be run every time a filesystem event is detected\n        // in the specified directories\n        io.debug(#(path, event))\n        Nil\n    })\n    |&gt; filespy.start()        // Start the watcher!\n\n    process.sleep_forever()\n}\n```\n\nIf you want to, you can also go lower level, and configure the underlying actor:\n\n```gleam\nimport filespy\nimport gleam/io\n\nfn main() {\n    let _res = filespy.new()        // Create the builder\n    |&gt; filespy.add_dir(&quot;.&quot;)         // Watch the current directory\n    |&gt; filespy.add_dir(&quot;/mnt&quot;)      // Watch the /mnt directory\n    |&gt; filespy.set_initial_state(0) // Initial state for the actor, this is required!\n    |&gt; filespy.set_actor_handler(fn (message, state) {\n        // This callback will be run every time a filesystem event is detected\n        // in the specified directories\n\n        // In the actor handler, multiple events might be sent at once.\n        let filespy.Change(path: path, events: events) = message\n        io.debug(#(path, events, state))\n        \n        actor.continue(state + 1)\n    })\n    |&gt; filespy.start()              // Start the watcher!\n\n    process.sleep_forever()\n}\n```\n\nYou can go even lower level, and get the actor start spec to configure it yourself:\n\n```gleam\nimport filespy\nimport gleam/io\n\nfn main() {\n    let start_spec = filespy.new()  // Create the builder\n    |&gt; filespy.add_dir(&quot;.&quot;)         // Watch the current directory\n    |&gt; filespy.add_dir(&quot;/mnt&quot;)      // Watch the /mnt directory\n    |&gt; filespy.set_initial_state(0) // Initial state for the actor, this is required!\n    |&gt; filespy.set_actor_handler(fn (message, state) {\n        // This callback will be run every time a filesystem event is detected\n        // in the specified directories\n\n        // In the actor handler, multiple events might be sent at once.\n        let filespy.Change(path: path, events: events) = message\n        io.debug(#(path, events, state))\n        \n        actor.continue(state + 1)\n    })\n    |&gt; filespy.spec()               // Get the spec\n\n    actor.start_spec(start_spec)\n\n    process.sleep_forever()\n}\n```\n\n## Documentation\nIf you have any more questions, check out the [documentation](https://hexdocs.pm/filespy)!\n","url":"index.html"},{"doc":"filespy","title":"ActorHandler","content":"pub type ActorHandler(a) =\n  fn(Change, a) -&gt; actor.Next(Change, a)\n Handler function used with an actor handler\n\nSynonyms:\nfilespy.ActorHandler\nfilespy ActorHandler","url":"filespy.html#ActorHandler"},{"doc":"filespy","title":"Builder","content":"pub opaque type Builder(a, d, h, s)\n Opaque builder type to instantiate the listener\n\n Instantiate it with `new`.\n\nSynonyms:\nfilespy.Builder\nfilespy Builder","url":"filespy.html#Builder"},{"doc":"filespy","title":"Change","content":"pub type Change {\n  Change(path: String, events: List(Event))\n}\n A filesystem change\nChange(path: String, events: List(Event))\n\n\nSynonyms:\nfilespy.Change\nfilespy Change","url":"filespy.html#Change"},{"doc":"filespy","title":"Event","content":"pub type Event {\n  Created\n  Modified\n  Closed\n  Deleted\n  Renamed\n  Attribute\n  Unknown(Atom)\n}\n Possible filesystem events\nCreated\n\n\nModified\n\n\nClosed\n\n\nDeleted\n\n\nRenamed\n\n\nAttribute\n\n\nUnknown(Atom)\n\n\nSynonyms:\nfilespy.Event\nfilespy Event","url":"filespy.html#Event"},{"doc":"filespy","title":"Handler","content":"pub type Handler =\n  fn(String, Event) -&gt; Nil\n Handler function called when an event is detected\n\nSynonyms:\nfilespy.Handler\nfilespy Handler","url":"filespy.html#Handler"},{"doc":"filespy","title":"HasDirectories","content":"pub type HasDirectories\n Phantom type to indicate the Builder has directories\n\nSynonyms:\nfilespy.HasDirectories\nfilespy HasDirectories","url":"filespy.html#HasDirectories"},{"doc":"filespy","title":"HasHandler","content":"pub type HasHandler\n Phantom type to indicate the Builder has a handler\n\nSynonyms:\nfilespy.HasHandler\nfilespy HasHandler","url":"filespy.html#HasHandler"},{"doc":"filespy","title":"HasInitialState","content":"pub type HasInitialState\n Phantom type to indicate the Builder has an initial state\n\nSynonyms:\nfilespy.HasInitialState\nfilespy HasInitialState","url":"filespy.html#HasInitialState"},{"doc":"filespy","title":"NoDirectories","content":"pub type NoDirectories\n Phantom type to indicate the Builder has no directories\n\nSynonyms:\nfilespy.NoDirectories\nfilespy NoDirectories","url":"filespy.html#NoDirectories"},{"doc":"filespy","title":"NoHandler","content":"pub type NoHandler\n Phantom type to indicate the Builder has no handlers\n\nSynonyms:\nfilespy.NoHandler\nfilespy NoHandler","url":"filespy.html#NoHandler"},{"doc":"filespy","title":"NoInitialState","content":"pub type NoInitialState\n Phantom type to indicate the Builder has no initial state\n\nSynonyms:\nfilespy.NoInitialState\nfilespy NoInitialState","url":"filespy.html#NoInitialState"},{"doc":"filespy","title":"add_dir","content":"pub fn add_dir(builder: Builder(a, b, c, d), directory: String) -&gt; Builder(\n  a,\n  HasDirectories,\n  c,\n  d,\n)\n Add a directory to watch\n\n # Examples\n \n \n filespy.new()\n |&gt; filespy.add_dir(&quot;./watched&quot;)\n \nSynonyms:\nfilespy.add_dir\nfilespy add_dir","url":"filespy.html#add_dir"},{"doc":"filespy","title":"new","content":"pub fn new() -&gt; Builder(\n  a,\n  NoDirectories,\n  NoHandler,\n  NoInitialState,\n)\n Create a new builder\n\n Use this with the `add_dir` and `handler` functions to configure the\n watcher\nSynonyms:\nfilespy.new\nfilespy new","url":"filespy.html#new"},{"doc":"filespy","title":"selector","content":"pub fn selector() -&gt; Selector(Change)\n Get a `Selector` which can be used to select for filesystem events.\nSynonyms:\nfilespy.selector\nfilespy selector","url":"filespy.html#selector"},{"doc":"filespy","title":"set_actor_handler","content":"pub fn set_actor_handler(builder: Builder(a, b, NoHandler, c), handler: fn(\n    Change,\n    a,\n  ) -&gt; Next(Change, a)) -&gt; Builder(a, b, HasHandler, c)\n Set the actor handler\n\n Use this if you want to have a more thorough control over the generated\n actor. You will also need to set an initial state, with `set_initial_state`.\nSynonyms:\nfilespy.set_actor_handler\nfilespy set_actor_handler","url":"filespy.html#set_actor_handler"},{"doc":"filespy","title":"set_handler","content":"pub fn set_handler(builder: Builder(\n    Nil,\n    a,\n    NoHandler,\n    NoInitialState,\n  ), handler: fn(String, Event) -&gt; Nil) -&gt; Builder(\n  Nil,\n  a,\n  HasHandler,\n  HasInitialState,\n)\n Set the handler\n\n # Examples\n\n \n filespy.new()\n |&gt; filespy.add_dir(&quot;./watched&quot;)\n |&gt; filespy.set_handler(fn (path: String, event: filespy.Event) {\n     case event {\n       filespy.Created -&gt; {\n         io.println(&quot;File &quot; &lt;&gt; path &lt;&gt; &quot; created&quot;)\n       }\n       _ -&gt; {\n         io.println(&quot;Something else happened to &quot; &lt;&gt; path)\n       }\n   }\n })\nSynonyms:\nfilespy.set_handler\nfilespy set_handler","url":"filespy.html#set_handler"},{"doc":"filespy","title":"set_initial_state","content":"pub fn set_initial_state(builder: Builder(a, b, c, NoInitialState), state: a) -&gt; Builder(\n  a,\n  b,\n  c,\n  HasInitialState,\n)\n Set the initial state\n\n Use this if you want to have a more thorough control over the generated\n actor. You&#39;ll only have access to this state if you set your handler with\n `set_actor_handler`.\nSynonyms:\nfilespy.set_initial_state\nfilespy set_initial_state","url":"filespy.html#set_initial_state"},{"doc":"filespy","title":"spec","content":"pub fn spec(builder: Builder(\n    a,\n    HasDirectories,\n    HasHandler,\n    HasInitialState,\n  )) -&gt; Spec(a, Change)\n Get an actor `Spec` for the watcher\nSynonyms:\nfilespy.spec\nfilespy spec","url":"filespy.html#spec"},{"doc":"filespy","title":"start","content":"pub fn start(builder: Builder(\n    a,\n    HasDirectories,\n    HasHandler,\n    HasInitialState,\n  )) -&gt; Result(Subject(Change), StartError)\n Start an actor which will receive filesystem events\n\n In order for this to work, you&#39;ll need to have set some directories to be\n watched, with `add_dir`, and set a handler with either `set_handler` or\n `set_actor_handler` and `set_initial_state`.\nSynonyms:\nfilespy.start\nfilespy start","url":"filespy.html#start"},{"doc":"filespy","title":"filespy","content":" This module is a wrapper around the erlang [FS](https://fs.n2o.dev/)\n library. It allows you to create a listener for file change events for any\n operating system.\n\n Note: on Linux and BSD, you need `inotify-tools` installed.","url":"filespy.html"}]);